// Copyright (c) 2022 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#pragma once
#include "dawnlibs.hpp"
#include "Card.hpp"

#define POKER_WINNING_CONFIDENCE_ROYAL_FLUSH 1.0f
#define POKER_WINNING_CONFIDENCE_STRAIGHT_FLUSH 0.99f
#define POKER_WINNING_CONFIDENCE_FOUR_OF_A_KIND 0.9f
#define POKER_WINNING_CONFIDENCE_FULL_HOUSE 0.85f
#define POKER_WINNING_CONFIDENCE_FLUSH 0.8f
#define POKER_WINNING_CONFIDENCE_STRAIGHT 0.7f
#define POKER_WINNING_CONFIDENCE_THREE_OF_A_KIND 0.5f
#define POKER_WINNING_CONFIDENCE_TWO_PAIR 0.4f
#define POKER_WINNING_CONFIDENCE_PAIR 0.2f
#define POKER_WINNING_CONFIDENCE_HIGH_CARD 0.1f

namespace Dawn {
  enum PokerWinningType {
    POKER_WINNING_TYPE_NULL,
    POKER_WINNING_TYPE_ROYAL_FLUSH,
    POKER_WINNING_TYPE_STRAIGHT_FLUSH,
    POKER_WINNING_TYPE_FOUR_OF_A_KIND,
    POKER_WINNING_TYPE_FULL_HOUSE,
    POKER_WINNING_TYPE_FLUSH,
    POKER_WINNING_TYPE_STRAIGHT,
    POKER_WINNING_TYPE_THREE_OF_A_KIND,
    POKER_WINNING_TYPE_TWO_PAIR,
    POKER_WINNING_TYPE_PAIR,
    POKER_WINNING_TYPE_HIGH_CARD
  };

  struct PokerWinning {
    public:
      enum PokerWinningType type;
      std::vector<struct Card> full;
      
      static float_t getWinningTypeConfidence(enum PokerWinningType type);
  };
}